@@ -26,7 +26,6 @@
 #include <time.h>
 
 #include <glib.h>
-#include <gnome.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
 
@@ -140,6 +139,10 @@ list__process_line (char     *line,
 		return;
 
 	line_l = strlen (line);
+
+	if (line_l == 0)
+		return;
+
 	if (line_l > EMPTY_ARCHIVE_WARNING_LENGTH) 
 		if (strcmp (line + line_l - EMPTY_ARCHIVE_WARNING_LENGTH, 
 			    EMPTY_ARCHIVE_WARNING) == 0) {
@@ -217,8 +220,6 @@ add_password_arg (FRCommand     *comm,
 static void
 fr_command_zip_list (FRCommand *comm)
 {
-
-
 	FR_COMMAND_ZIP (comm)->is_empty = FALSE;
 
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
@@ -250,6 +251,7 @@ process_line__common (char     *line,
 		double fraction = (double) comm->n_file++ / comm->n_files;
 		fr_command_progress (comm, fraction);
 	}
+
 }
 
 
